==> qt6-qt3d-6.6.3.tgz: lib/cmake/Qt63DInput/Qt63DInputAdditionalTargetInfo.cmake <==
# Additional target information for Qt63DInput
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::3DInput)
get_target_property(_qt_imported_location Qt6::3DInput IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_soname Qt6::3DInput IMPORTED_SONAME_RELEASE)
get_target_property(_qt_imported_location_default Qt6::3DInput IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_soname_default Qt6::3DInput IMPORTED_SONAME_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::3DInput" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::3DInput APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_SONAME_RELWITHDEBINFO "${_qt_imported_soname}")
endif()

# Import target "Qt6::3DInput" for configuration "MinSizeRel"
set_property(TARGET Qt6::3DInput APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_SONAME_MINSIZEREL "${_qt_imported_soname}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()
if(_qt_imported_soname_default)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_SONAME "${_qt_imported_soname_default}")
endif()
__qt_internal_promote_target_to_global_checked(Qt6::3DInputPrivate)

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_objects)
unset(_qt_imported_objects_default)
unset(_qt_imported_clr)
unset(_qt_imported_clr_default)
unset(_qt_imported_configs)

==> qt6-qt3d-6.8.3.tgz: lib/cmake/Qt63DInput/Qt63DInputAdditionalTargetInfo.cmake <==
# Additional target information for Qt63DInput
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::3DInput)
get_target_property(_qt_imported_location Qt6::3DInput IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_soname Qt6::3DInput IMPORTED_SONAME_RELEASE)
get_target_property(_qt_imported_link_dependencies Qt6::3DInput IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE)
get_target_property(_qt_imported_location_default Qt6::3DInput IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_soname_default Qt6::3DInput IMPORTED_SONAME_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_link_dependencies_default Qt6::3DInput IMPORTED_LINK_DEPENDENT_LIBRARIES_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::3DInput" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::3DInput APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_SONAME_RELWITHDEBINFO "${_qt_imported_soname}")
endif()
if(_qt_imported_link_dependencies)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "${_qt_imported_link_dependencies}")
endif()

# Import target "Qt6::3DInput" for configuration "MinSizeRel"
set_property(TARGET Qt6::3DInput APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_SONAME_MINSIZEREL "${_qt_imported_soname}")
endif()
if(_qt_imported_link_dependencies)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LINK_DEPENDENT_LIBRARIES_MINSIZEREL "${_qt_imported_link_dependencies}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()
if(_qt_imported_soname_default)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_SONAME "${_qt_imported_soname_default}")
endif()
if(_qt_imported_link_dependencies_default)
    set_property(TARGET Qt6::3DInput PROPERTY IMPORTED_LINK_DEPENDENT_LIBRARIES "${_qt_imported_link_dependencies_default}")
endif()
__qt_internal_promote_target_to_global_checked(Qt6::3DInputPrivate)

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_link_dependencies)
unset(_qt_imported_link_dependencies_default)
unset(_qt_imported_objects)
unset(_qt_imported_objects_default)
unset(_qt_imported_clr)
unset(_qt_imported_clr_default)
unset(_qt_imported_configs)
